@@ -8,20 +8,15 @@ function(fit, ensembleData, thresholds, dates = NULL, ...)
  nForecasts <- ensembleSize(ensembleData)
  if (!all(M == 1:nForecasts)) ensembleData <- ensembleData[,M]
 
-# remove instances missing all forecasts, obs, or dates
+## remove instances missing all forecasts
 
  M <- apply(ensembleForecasts(ensembleData), 1, function(z) all(is.na(z)))
  M <- M | is.na(ensembleVerifObs(ensembleData))
- M <- M | is.na(ensembleDates(ensembleData))
  ensembleData <- ensembleData[!M,]
  
- if (is.null(y <- ensembleVerifObs(ensembleData)))
-  stop("verification observations required")
+## match specified dates with dateTable in fit
 
-#nObs <- length(y)
- nObs <- ensembleNobs(ensembleData) 
-
- dateTable <- names(fit$nIter)
+ dateTable <- dimnames(fit$weights)[[2]]
 
  if (!is.null(dates)) {
 
@@ -33,7 +28,7 @@ function(fit, ensembleData, thresholds, dates = NULL, ...)
    K <- match( dates, dateTable, nomatch=0)
 
    if (any(!K) || !length(K)) 
-     stop("parameters not available for a some dates")
+     stop("parameters not available for some dates")
 
  }
  else {
@@ -41,28 +36,36 @@ function(fit, ensembleData, thresholds, dates = NULL, ...)
    dates <- dateTable
    K <- 1:length(dateTable)
 
- }
+  }
+
+ ensDates <- ensembleDates(ensembleData)
 
 ## match dates in data with dateTable
- if (is.null(ensDates <- ensembleDates(ensembleData))) {
+ if (is.null(ensDates) || all(is.na(ensDates))) {
    if (length(dates) > 1) stop("date ambiguity")
+   nObs <- nrow(ensembleData)
    Dates <- rep( dates, nObs)
  }
  else {
+## remove instances missing dates
+   if (any(M <- is.na(ensDates))) {
+     ensembleData <- ensembleData[!M,]
+     ensDates <- ensembleDates(ensembleData)
+   }
    Dates <- as.character(ensDates)
-   L <- as.logical(match(Dates, dates, nomatch=0))
+   L <- as.logical(match( Dates, dates, nomatch=0))
    if (all(!L) || !length(L)) 
      stop("model fit dates incompatible with ensemble data")
    Dates <- Dates[L]
    ensembleData <- ensembleData[L,]
-   y <- y[L]
+   nObs <- length(Dates)
  }
 
- nObs <- length(y)
-
+ y <- ensembleVerifObs(ensembleData)
  nForecasts <- ensembleSize(ensembleData) 
 
  ensembleData <- ensembleForecasts(ensembleData)
+
  x <- sapply(apply( ensembleData, 1, mean, na.rm = TRUE), fit$transformation)
  
  MAT <-  outer(y, thresholds, "<=")
@@ -98,6 +101,7 @@ logisticFit <- sapply( thresholds,
 # BMA Brier Scores
 
     l <- l + 1
+
     k <- K[l]
 
     WEIGHTS <- fit$weights[,k]
