@@ -7,24 +7,21 @@ function(fit, ensembleData, values, dates = NULL, ...)
  nForecasts <- ensembleSize(ensembleData)
  if (!all(M == 1:nForecasts)) ensembleData <- ensembleData[,M]
 
-# remove instances missing all forecasts or dates
+## remove instances missing all forecasts
 
  M <- apply(ensembleForecasts(ensembleData), 1, function(z) all(is.na(z)))
- M <- M | is.na(ensembleDates(ensembleData))
  ensembleData <- ensembleData[!M,]
  
- nObs <- nrow(ensembleData)
-
 ## match specified dates with dateTable in fit
 
- dateTable <- names(fit$nIter)
+ dateTable <- dimnames(fit$weights)[[2]]
 
  if (!is.null(dates)) {
 
    dates <- sort(unique(as.character(dates)))
 
    if (length(dates) > length(dateTable)) 
-     stop("parameters not available for a some dates")
+     stop("parameters not available for some dates")
 
    K <- match( dates, dateTable, nomatch=0)
 
@@ -37,16 +34,22 @@ function(fit, ensembleData, values, dates = NULL, ...)
    dates <- dateTable
    K <- 1:length(dateTable)
 
- }
+  }
+
+ ensDates <- ensembleDates(ensembleData)
 
 ## match dates in data with dateTable
- if (is.null(ensDates <- ensembleDates(ensembleData))) {
-
+ if (is.null(ensDates) || all(is.na(ensDates))) {
    if (length(dates) > 1) stop("date ambiguity")
-
+   nObs <- nrow(ensembleData)
    Dates <- rep( dates, nObs)
  }
  else {
+## remove instances missing dates
+   if (any(M <- is.na(ensDates))) {
+     ensembleData <- ensembleData[!M,]
+     ensDates <- ensembleDates(ensembleData)
+   }
    Dates <- as.character(ensDates)
    L <- as.logical(match( Dates, dates, nomatch=0))
    if (all(!L) || !length(L)) 
@@ -55,6 +58,8 @@ function(fit, ensembleData, values, dates = NULL, ...)
    ensembleData <- ensembleData[L,]
    nObs <- length(Dates)
  }
+
+ nForecasts <- ensembleSize(ensembleData)
  
  CDF <- matrix( NA, nrow = nObs, ncol = length(values))
  dimnames(CDF) <- list(ensembleObsLabels(ensembleData), as.character(values)) 
